summaryrefslogtreecommitdiffstats
path: root/kig/misc/kigfiledialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kig/misc/kigfiledialog.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kig/misc/kigfiledialog.h')
-rw-r--r--kig/misc/kigfiledialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kig/misc/kigfiledialog.h b/kig/misc/kigfiledialog.h
index 5fb65949..8a299bf5 100644
--- a/kig/misc/kigfiledialog.h
+++ b/kig/misc/kigfiledialog.h
@@ -46,17 +46,17 @@ public:
* documentation of KFileDialog for more help about this
* \param filter the filter for the file dialog
* \param caption the caption of this file dialog
* \param tqparent the tqparent for this file dialog
*/
KigFileDialog( const TQString& startDir, const TQString& filter,
- const TQString& caption, TQWidget *tqparent );
+ const TQString& caption, TQWidget *parent );
/**
* Use this to set the widget containing the options of eg an export filter.
* The option widget will be popped up in a dialog right after the user
* presses OK and before the dialog is closed.
*
* You can construct the option widget with no tqparent, as it will be
* reparented.
*
* \param w the option widget
@@ -46,17 +46,17 @@ public:
* \param filter the filter for the file dialog
* \param caption the caption of this file dialog
- * \param tqparent the tqparent for this file dialog
+ * \param parent the parent for this file dialog
*/
KigFileDialog( const TQString& startDir, const TQString& filter,
@@ -46,17 +46,17 @@ public:
* presses OK and before the dialog is closed.
*
- * You can construct the option widget with no tqparent, as it will be
+ * You can construct the option widget with no parent, as it will be
* reparented.
*